#!/bin/bash

# Author: Matt Stevens
# The Emsworth Computer Company Ltd.
# (c) 2023 All Rights Reserved
# Modify as you will

# Wait trigger script
# pass the sleep time and a pid file in that order
# the script sleeps for the specified time before calling an action

WAIT_TIME=$1
if ([ -z "$WAIT_TIME" ]); then
	#wait time was not provided, set a default
	WAIT_TIME="30"
	echo "WAIT_TIME defaults to $WAIT_TIME"
fi

WAIT_PIDFILE=$2
if ([ -z $WAIT_PIDFILE ]); then
	#pid file not provided, set a default
	WAIT_PIDFILE="$HOME/wait_.pid"
	echo "WAIT_PIDFILE defaults to $WAIT_PIDFILE"
fi

if !([ -f $WAIT_PIDFILE ]); then
	#pid file does not exist, create one
	echo $$ > $WAIT_PIDFILE
	echo "Created pid file"
fi

TRIGGER_CMD="echo BANG! BANG!"
#TRIGGER_CMD="uhubctl -p 2 -a"

echo "Waiting for $WAIT_TIME"
sleep $WAIT_TIME
echo "Finished waiting"
echo "Pull the trigger"
	
# Trigger the command
if !([ -z "$TRIGGER_CMD" ]); then

	$TRIGGER_CMD
else
	echo "Chamber is empty(!)"
fi

# clean up
if ([ -f $WAIT_PIDFILE ]); then
	#pid file is present, remove it
	rm ${WAIT_PIDFILE}
	echo "Removed $WAIT_PIDFILE"
fi

