#!/bin/bash

# Author: Matt Stevens
# The Emsworth Computer Company Ltd.
# (c) 2023 All Rights Reserved
# Modify as you will

# Monitor local MPD status
# Trigger watchdog script when player is stopped or paused
# Cancel watchdog when player becomes active
# Should be scheduled with cron or systemd
# Must be called at least twice within the waiting period
# Depends on: netcat

# return the path the script was launched from
function script_path {
	local _PATH="$(dirname -- "${BASH_SOURCE[0]}")"            # relative
	_PATH="$(cd -- "$_PATH" && pwd)"    # absolutized and normalized
	if [[ -z "$_PATH" ]] ; then
  		# error; The path is not accessible
  		# to the script (e.g. permissions re-evaled after suid)
		echo "Check script persmission"
  	exit 1  # fail
	fi
	 
	echo "$_PATH"
}

WAIT_TIME="1m"
WAIT_CMD="$(script_path)/wait_.sh"
WAIT_PIDFILE="$HOME/wait_.pid"

#get active PID from file
if ([ -f "$WAIT_PIDFILE" ]); then
	#pid file exists, read it
	WAIT_PID=$(<$WAIT_PIDFILE)
fi

#get mpd state
MPD_STATE=$(echo "status" | nc -q 1 localhost 6600 | grep -oP "(?<=state:\s)pause|stop$")

#test MPD state
if !([ ${#MPD_STATE} -gt 0 ]); then
	#state returned empty, mpd is playing
	echo "Player is active"

	if !([ -z ${WAIT_PID} ]); then
		#wait_.sh is running, clean it up. 
		# Kill wait_.sh process and remove pid file 
		echo "Kill usb_wait pid ${WAIT_PID}"
		kill $WAIT_PID
		rm $WAIT_PIDFILE
	fi
else
	#state returned a result, mpd must be stopped or paused
	echo "Player is idle"

	if ([ -z "$WAIT_PID" ]); then
		#wait_pid is empty, usb wait is not active
		echo "Trigger in ${WAIT_TIME}"

		#spawn the wait process and save the new PID
		$WAIT_CMD $WAIT_TIME $WAIT_PIDFILE &
		echo $! > ${WAIT_PIDFILE}
		echo "Wait PID = $!"
	else
		echo "Trigger is already waiting"
	fi
fi
